about summary refs log tree commit diff
path: root/src/test/run-fail
diff options
context:
space:
mode:
authorMatthias Krüger <matthias.krueger@famsik.de>2018-08-19 15:30:23 +0200
committerMatthias Krüger <matthias.krueger@famsik.de>2018-08-19 17:41:28 +0200
commit71120ef1e5cb885ee45e6148970db6ce93ce1aca (patch)
tree9358c738c8943f0bc0b65303818237a801b8b0e1 /src/test/run-fail
parenta9fe312b98d5a6b194c4ad1a17dcf258ba9941ea (diff)
downloadrust-71120ef1e5cb885ee45e6148970db6ce93ce1aca.tar.gz
rust-71120ef1e5cb885ee45e6148970db6ce93ce1aca.zip
Fix typos found by codespell.
Diffstat (limited to 'src/test/run-fail')
-rw-r--r--src/test/run-fail/run-unexported-tests.rs4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/test/run-fail/run-unexported-tests.rs b/src/test/run-fail/run-unexported-tests.rs
index 3f75229948d..c7d5574f909 100644
--- a/src/test/run-fail/run-unexported-tests.rs
+++ b/src/test/run-fail/run-unexported-tests.rs
@@ -8,7 +8,7 @@
 // option. This file may not be copied, modified, or distributed
 // except according to those terms.
 
 // error-pattern:runned an unexported test
 // compile-flags:--test
 // check-stdout
 
@@ -17,6 +17,6 @@ mod m {
 
     #[test]
     fn unexported() {
-        panic!("runned an unexported test");
+        panic!("ran an unexported test");
     }
 }
@@ -8,7 +8,7 @@
 // except according to those terms.
 
-// error-pattern:runned an unexported test
+// error-pattern:ran an unexported test
 // compile-flags:--test
 // check-stdout